#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor qt5%{nil}
%if "%{flavor}" != ""
%define psuffix -%{flavor}
%else
%define psuffix %{nil}
%endif
#fixes build failure caused by new .debug files, not sure how to fix correctly
%define mname graphviz
# name of the plugin config file that dot creates
%define config_file config6
%if "%{flavor}" == "addons"
%define phpconf_dir %{_sysconfdir}/php%{php_version}/conf.d
%define phpext_dir  %(%{__php_config} --extension-dir)
%define ruby_version $(pkg-config --variable=RUBY_API_VERSION %{_libdir}/pkgconfig/ruby-*.pc)
# PHP8 requires swig >= 4.1.0, https://github.com/swig/swig/commit/56d74355735f3661406d69d04d89d1bdb4ca96f9
%if 0%{?suse_version} >= 1599
%define php_version 8
%else
%define php_version 7
%endif
%endif
# No pkgconfig(gts) in sle12 GA or SPx, but in sle15
%if 0%{?suse_version} == 1315 && !0%{?is_opensuse}
%bcond_with    gts
%else
%bcond_without gts
%endif
%define cdt_soversion 5
%define cgraph_soversion 6
%define gvc_soversion 6
%define gvpr_soversion 2
%define lab_gamut_soversion 1
%define pathplan_soversion 4
%define xdot_soversion 4
# Java and ocaml are not in ring1, thus this gets overriden in staging
# Also, both install into generic locations instead of a language
# specific prefix, disable both
%bcond_with    java
%bcond_with    ocaml
Name:           graphviz%{psuffix}
Version:        2.49.3
Release:        11.2
Summary:        Graph Visualization Tools
License:        EPL-1.0
Group:          Productivity/Graphics/Visualization/Graph
URL:            https://www.graphviz.org/
Source0:        https://gitlab.com/graphviz/graphviz/-/archive/%version/graphviz-%{version}.tar.bz2
Source1:        graphviz-rpmlintrc
#PATCH-FIX-UPSTREAM add flags to also link against libGLU and libGL
Patch0:         graphviz-smyrna-link_against_glu.patch
Patch1:         graphviz-fix-pkgIndex.patch
#PATCH-FIX-UPSTREAM Off-by-one bug
Patch2:         graphviz-array_overflow.patch
Patch3:         graphviz-2.20.2-interpreter_names.patch
#PATCH-FIX-UPSTREAM Don't warn about harmless issues with swig generated code
Patch4:         graphviz-useless_warnings.patch
Patch5:         graphviz-no_strict_aliasing.patch
Patch6:         graphviz-no_php_extra_libs.patch
# https://gitlab.com/graphviz/graphviz/-/issues/2303
Patch7:         swig-4.1.0.patch
#PATCH-FIX-UPSTREAM gvc: detect plugin installation failure and display an error
Patch8:         gvc-detect-plugin-installation-failure-and-display-an-error.patch
#PATCH-FIX-OPENSUSE Bug 1225776 - Flavor addons of package graphviz does not build with gcc14
Patch9:         graphviz-2.49.3-boo1225776-gcc14.patch
#PATCH-FIX-UPSTREAM
Patch10:        graphviz-87cc546.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  groff
BuildRequires:  guile-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(zlib)
Requires:       bitstream-vera-fonts
Requires:       graphviz-plugins-core = %{version}
Recommends:     graphviz-gd = %{version}
%if %{with gts}
BuildRequires:  pkgconfig(gts)
%endif
%if "%{flavor}" == "addons"
BuildRequires:  freeglut-devel
BuildRequires:  ghostscript
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libwebp-devel
BuildRequires:  perl
BuildRequires:  ruby-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2) >= 2
BuildRequires:  pkgconfig(gdlib)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gtkglext-1.0)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(ijs)
BuildRequires:  pkgconfig(libglade-2.0)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(tcl)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xext)
%if %{php_version} == 8
BuildRequires:  php8-devel
BuildRequires:  swig >= 4.1.0
%else
BuildRequires:  php7-devel
BuildRequires:  swig >= 3.0.11
%endif
%if %{with java}
BuildRequires:  java-devel >= 1.6.0
%endif
%if %{with ocaml}
BuildRequires:  ocaml
%endif
%endif
%if "%{flavor}" == "qt5"
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
%endif

%description
A collection of tools and tcl packages for the manipulation and layout
of graphs (as in nodes and edges, not as in bar charts).

%if "%{flavor}" == "qt5"
%package -n graphviz-gvedit
Summary:        Graph editor based on Qt
Group:          Productivity/Graphics/Visualization/Graph
Requires:       graphviz

%description -n graphviz-gvedit
The Qt5 graph editor included with graphviz.
%endif

%package -n graphviz-smyrna
Summary:        Large graph viewer
Group:          Productivity/Graphics/Visualization/Graph
Requires:       graphviz

%description -n graphviz-smyrna
Experimental large graph viewer using graphviz

%package -n graphviz-gnome
Summary:        Graphviz plugins that use gtk/GNOME
Group:          Productivity/Graphics/Visualization/Graph
Requires(post): graphviz = %{version}
Supplements:    (graphviz and xorg-x11-fonts-core)

%description -n graphviz-gnome
Graphviz plugins that use gtk/GNOME.

%package -n graphviz-gd
Summary:        Graphviz plugin for renderers based on gd
Group:          Productivity/Graphics/Visualization/Graph
Requires(post): graphviz >= %{version}

%description -n graphviz-gd
The graphviz-gd package contains the gd extensions for the graphviz
tools.

%package -n graphviz-guile
Summary:        Graph Visualization Tools
Group:          Productivity/Graphics/Visualization/Graph
Requires:       graphviz = %{version}
Requires:       guile

%description -n graphviz-guile
A collection of tools and tcl packages for the manipulation and layout
of graphs (as in nodes and edges, not as in bar charts).

%package -n graphviz-java
Summary:        Graph Visualization Tools
Group:          Productivity/Graphics/Visualization/Graph
Requires:       graphviz = %{version}
Requires:       java

%description -n graphviz-java
A collection of tools and tcl packages for the manipulation and layout
of graphs (as in nodes and edges, not as in bar charts).

%package -n graphviz-x11
Summary:        Graph editors based on X11
Group:          Productivity/Graphics/Visualization/Graph
Requires:       graphviz

%description -n graphviz-x11
The lefty/dotty/lneato X11 graph editors included with graphviz.

%package -n graphviz-lua
Summary:        Lua extension for graphviz
Group:          Productivity/Graphics/Visualization/Graph
Requires:       graphviz = %{version}
Requires:       lua

%description -n graphviz-lua
The graphviz-lua package contains the lua extension for the graphviz
tools.

%package -n graphviz-ocaml
Summary:        OCAML extension for graphviz
Group:          Productivity/Graphics/Visualization/Graph
Requires:       graphviz = %{version}
Requires:       ocaml

%description -n graphviz-ocaml
The graphviz-ocaml package contains the Objective Caml extension for
the graphviz tools.

%package -n graphviz-perl
Summary:        Perl extension for Graphviz
Group:          Productivity/Graphics/Visualization/Graph
Requires:       graphviz = %{version}
Requires:       perl = %{perl_version}

%description -n graphviz-perl
The graphviz-perl package contains the Perl extension for the graphviz
tools.

%package -n graphviz-php
Summary:        PHP Extension for Graphviz
Group:          Productivity/Graphics/Visualization/Graph
Requires:       graphviz = %{version}
Requires:       php%{php_version}
Requires:       php(api) = %{php_core_api}
Requires:       php(zend-abi) = %{php_zend_api}

%description -n graphviz-php
The graphviz-php package contains the PHP extension for the graphviz
tools.

%package -n python3-gv
Summary:        Python 3 Extension for Graphviz
Group:          Productivity/Graphics/Visualization/Graph
Requires:       graphviz = %{version}

%description -n python3-gv
The package contains the Python extension for the
graphviz tools.

%package -n graphviz-ruby
Summary:        Ruby Extension for Graphviz
Group:          Productivity/Graphics/Visualization/Graph
Requires:       graphviz = %{version}
Requires:       ruby

%description -n graphviz-ruby
The graphviz-ruby package contains the ruby extension for the graphviz
tools.

%package -n graphviz-tcl
Summary:        Tcl extension tools for graphviz
Group:          Development/Libraries/Tcl
Requires:       graphviz = %{version}
Requires:       tcl >= 8.3
Requires:       tk

%description -n graphviz-tcl
The graphviz-tcl package contains the various tcl packages (extensions)
for the graphviz tools.

%package -n graphviz-webp
Summary:        WebP support for graphviz
Group:          Productivity/Graphics/Visualization/Graph
Requires:       graphviz = %{version}
# depends on cairo in libgvplugin_pango
Requires:       graphviz-gnome = %{version}
Requires(post): graphviz >= %{version}

%description -n graphviz-webp
The graphviz-webp package contains files needed for the support of WebP images

%package -n graphviz-doc
Summary:        Documentation for graphviz
Group:          Documentation/Howto

%description -n graphviz-doc
Provides some additional PDF and HTML documentation for graphviz.

%package -n libcdt%{cdt_soversion}
Summary:        Container data types for Graphviz
Group:          System/Libraries

%description -n libcdt%{cdt_soversion}
Library providing container data types for Graphviz.

%package -n libcgraph%{cgraph_soversion}
Summary:        Library for graph programming
Group:          System/Libraries

%description -n libcgraph%{cgraph_soversion}
Libcgraph supports graph programming by maintaining graphs in memory and
reading and writing graph files. Graphs are composed of nodes, edges, and
nested subgraphs. These graph objects may be attributed with string
name-value pairs and programmer-defined records.

%package -n libgvc%{gvc_soversion}
Summary:        Graphviz context library
Group:          System/Libraries
Provides:       libgraphviz6:%{_libdir}/libgvc.so.6
Obsoletes:      libgraphviz6 < %{version}-%{release}

%description -n libgvc%{gvc_soversion}
libgvc provides a context for applications wishing to manipulate and render
graphs. It provides a command line parsing, common rendering code, and a
plugin mechanism for renderers.

%package -n libgvpr%{gvpr_soversion}
Summary:        Library for graph filtering
Group:          System/Libraries
Provides:       libgraphviz6:%{_libdir}/libgvpr.so.2
Obsoletes:      libgraphviz6 < %{version}-%{release}

%description -n libgvpr%{gvpr_soversion}
The gvpr library allows an application to perform general-purpose graph
manipulation and filtering based on an awk-like language

%package -n libpathplan%{pathplan_soversion}
Summary:        Library for finding smooth shortest paths
Group:          System/Libraries
Provides:       libgraphviz6:%{_libdir}/libpathplan.so.4
Obsoletes:      libgraphviz6 < %{version}-%{release}

%description -n libpathplan%{pathplan_soversion}
The pathplan library contains functions for finding shortest paths in polygons
in fitting bezier curves to those paths.

%package -n libxdot%{xdot_soversion}
Summary:        Library for parsing and deparsing of xdot operations
Group:          System/Libraries
Provides:       libgraphviz6:%{_libdir}/libxdot.so.4
Obsoletes:      libgraphviz6 < %{version}-%{release}

%description -n libxdot%{xdot_soversion}
The libxdot library provides support for parsing and deparsing graphical
operations specified by the xdot language.

%package -n liblab_gamut%{lab_gamut_soversion}
Summary:        Library containing a rich set of graph drawing tools
Group:          System/Libraries
Provides:       libgraphviz6:%{_libdir}/liblab_gamut.so.1
Obsoletes:      libgraphviz6 < %{version}-%{release}

%description -n liblab_gamut%{lab_gamut_soversion}
The lab_gamut library contains a rich set of graph drawing tools.

%package plugins-core
Summary:        Core plugins for graphviz
Group:          Productivity/Graphics/Visualization/Graph
# Needed for dot binary
Requires(post): %{mname}

%description plugins-core
Core plugins for graphviz:
 * libgvplugin_core
 * libgvplugin_dot_layout
 * libgvplugin_neato_layout

%package devel
Summary:        Graphviz development package
Group:          Development/Libraries/C and C++
Requires:       %{mname} = %{version}
Requires:       libcdt%{cdt_soversion} = %{version}
Requires:       libcgraph%{cgraph_soversion} = %{version}
Requires:       libgvc%{gvc_soversion} = %{version}
Requires:       libgvpr%{gvpr_soversion} = %{version}
Requires:       liblab_gamut%{lab_gamut_soversion} = %{version}
Requires:       libpathplan%{pathplan_soversion} = %{version}
Requires:       libxdot%{xdot_soversion} = %{version}

%description devel
The graphviz-devel package contains all that's necessary for developing
programs that use the graphviz libraries including man3 pages.

%prep
#autosetup breaks graphviz-addons
%setup -q -n %{mname}-%{version}
%patch -P 0
%patch -P 1
%patch -P 2
%patch -P 3
%patch -P 4
%patch -P 5 -p1
%patch -P 6
%patch -P 7 -p1
%patch -P 8 -p1
%patch -P 9
%patch -P 10

# pkg-config returns 0 (TRUE) when guile-2.2 is present
if pkg-config --atleast-version=2.2 guile-2.2; then
sed "s/guile-2.0/guile-2.2/" -i configure.ac
fi

rm -f contrib/gprof2dot.awk

# Fix path for lua/php install
sed -i \
    -e 's@LUA_INSTALL_DIR="/usr.*@LUA_INSTALL_DIR=%{lua_archdir}@' \
    -e 's@\(PHP_INSTALL_DIR=.*\)/php/modules@\1/php%{php_version}/extensions@' \
    -e 's@\(PHP_INSTALL_DATADIR=.*\)/php@\1/php%{php_version}@' \
    configure.ac

%build
./autogen.sh RUBY_VER=%{?ruby_version}
CFLAGS="%{optflags} -ffast-math -fno-strict-aliasing -fno-strict-overflow -fPIC"

%if "%{flavor}" == "addons"

CFLAGS="$CFLAGS -I/usr/include/ruby-%{ruby_version}.0 -fpermissive"
#seems to be broken? gives -I/usr/lib64/ruby/2.6.0/x86_64-linux-gnu, ruby.h is in /usr/lib64/ruby/2.6.0
#CFLAGS="$CFLAGS $(pkg-config --cflags ruby-$(echo {rb_ver} | sed 's|\.[^.]*$||'))"

%endif

export CFLAGS="$CFLAGS"
export CPPFLAGS="$CFLAGS"
export LDFLAGS="-pie"
%configure \
      --disable-static \
      --without-included-ltdl \
      --disable-ltdl-install \
      --with-ipsepcola \
      --without-ming \
      --disable-io \
      --without-visio \
%if "%{flavor}" == "addons"
      --with-x \
      --enable-lefty \
      --with-smyrna \
      RUBY_VER=%{ruby_version} \
%endif
%if "%{flavor}" == "qt5"
      --with-qt \
%endif
%if "%{flavor}" == ""
      --without-mylibgd \
      --without-libgd \
%endif
      --disable-silent-rules
make %{?_smp_mflags}

%install
make install \
      DESTDIR=%{buildroot} \
      docdir=%{buildroot}%{_docdir}/%{mname} \
      pkgconfigdir=%{_libdir}/pkgconfig

find %{buildroot} -type f -name "*.la" -delete -print

# Unversioned symlinks for plugins are pointless, and
# break shared library packaging policy
find %{buildroot}/%{_libdir}/graphviz/ -name "libgvplugin_*.so" -print -delete

mkdir -p %{buildroot}/%{_docdir}
mkdir -p %{buildroot}%{_datadir}/%{nmame}

rm -f %{buildroot}/%{_libdir}/%{mname}/pkgIndex.tcl
chmod -x %{buildroot}%{_datadir}/%{mname}/lefty/*

mkdir -p %{buildroot}%{_libdir}/graphviz
touch %{buildroot}%{_libdir}/graphviz/%{config_file}

#Correct the path to the shared library
for manfile in $(find %{buildroot} -name \*.man); do
    sed -i \
        -e 's$%{_prefix}/lib/graphviz$%{_libdir}/%{mname}$g' \
        $manfile
done

# There are no such binaries distributed by us
rm -f %{buildroot}%{_mandir}/man1/mingle.1

%if "%{flavor}" == "addons"
mkdir -p %{buildroot}/%{phpconf_dir}
cat > %{buildroot}%{phpconf_dir}/gv.ini <<EOF
; comment out next line to disable gv extension in php
extension = gv.so
EOF

# Fix doc location
cp -a %{buildroot}%{_datadir}/%{mname}/doc %{buildroot}%{_defaultdocdir}/%{mname}-doc
%fdupes %{buildroot}%{_defaultdocdir}/%{mname}-doc
%fdupes %{buildroot}%{_datadir}/graphviz/demo
%endif

%if "%{flavor}" == "addons" || "%{flavor}" == "qt5"
# Prune all the content of the base graphviz package
rm -rf %{buildroot}%{_libdir}/pkgconfig
rm -rf %{buildroot}%{_includedir}
rm -rf %{buildroot}%{_datadir}/graphviz/examples
rm -rf %{buildroot}%{_datadir}/graphviz/graphs
rm -rf %{buildroot}%{_datadir}/graphviz/gvpr
rm -f  %{buildroot}%{_mandir}/man3/*.3
rm -f  %{buildroot}%{_mandir}/man7/*.7
rm -f  %{buildroot}%{_libdir}/graphviz/%{config_file}
rm -f  %{buildroot}%{_libdir}/graphviz/libgvplugin_core*
rm -f  %{buildroot}%{_libdir}/graphviz/libgvplugin_dot_layout*
rm -f  %{buildroot}%{_libdir}/graphviz/libgvplugin_neato_layout*
# binaries removal
for i in acyclic bcomps ccomps circo cluster dijkstra dot dot2gxl dot_builtins edgepaint fdp gc gml2gv graphml2gv gv2gml gv2gxl gvcolor gvgen gvmap gvmap.sh gvpack gvpr gxl2dot gxl2gv mm2gv neato nop osage patchwork prune sccmap sfdp tred twopi unflatten vimdot; do
    rm -f %{buildroot}%{_bindir}/$i
    rm -f %{buildroot}%{_mandir}/man1/$i.1
done
# libraries removal
rm -f %{buildroot}%{_sysconfdir}/ld.so.conf.d/graphviz.conf
rm -f %{buildroot}%{_libdir}/lib{cdt,cgraph,gvc,gvpr,pathplan,xdot,lab_gamut}.so*
%endif
%if "%{flavor}" == "addons"
# Fix tcl locations
for lib in libgdtclft* libgv_tcl.so libtcldot* libtclplan* ; do
   mv %{buildroot}%{_libdir}/%{mname}/tcl/${lib} %{buildroot}%{_libdir}
done
# remove duplicated tcl files
for i in libgdtclft.so.0.0.0 libgv_tcl.so libtcldot.so.0.0.0 libtcldot_builtin.so.0.0.0 libtclplan.so.0.0.0; do
    rm -f %{buildroot}%{_libdir}/tcl8.6/graphviz/$i
    ln -s %{_libdir}/$i %{buildroot}%{_libdir}/tcl8.6/graphviz/$i
done
mkdir -p %{buildroot}%{_datadir}/tcl/%{mname}/
mv %{buildroot}%{_libdir}/%{mname}/tcl/pkgIndex.tcl %{buildroot}%{_datadir}/tcl/%{mname}/pkgIndex.tcl
# remove graphviz bindings from graphviz dir, these are installed into the language specific directories
rm -rf %{buildroot}%{_libdir}/graphviz/lua
rm -rf %{buildroot}%{_libdir}/graphviz/perl
rm -rf %{buildroot}%{_libdir}/graphviz/php
rm -rf %{buildroot}%{_libdir}/graphviz/python*
rm -rf %{buildroot}%{_libdir}/graphviz/ruby
%endif
%if "%{flavor}" == "" || "%{flavor}" == "qt5"
# These are part of gnome subpkg
rm -f %{buildroot}%{_libdir}/graphviz/libgvplugin_pango*
rm -f %{buildroot}%{_libdir}/graphviz/libgvplugin_xlib*
# This is part of the gd subpkg only
rm -f %{buildroot}%{_mandir}/man1/{diffimg.1*,dotty.1*,lefty.1*,lneato.1*}
rm -f %{buildroot}%{_bindir}/{dotty,lneato}
# This is part of the x11 subpkg only
rm -rf %{buildroot}%{_datadir}/graphviz/lefty
%endif
# Remove wrongly located docs
rm -rf %{buildroot}%{_datadir}/%{mname}/doc

%post plugins-core
# run "dot -c" to generate plugin config %%{_libdir}/graphviz/config
%{_bindir}/dot -c
test -s %{_libdir}/graphviz/%{config_file} || echo "%{_libdir}/graphviz/%{config_file} doesn't exist! Check installation."

%post -n libcdt%{cdt_soversion} -p /sbin/ldconfig

%postun -n libcdt%{cdt_soversion} -p /sbin/ldconfig

%post -n libcgraph%{cgraph_soversion} -p /sbin/ldconfig

%postun -n libcgraph%{cgraph_soversion} -p /sbin/ldconfig

%post -n libgvc%{gvc_soversion} -p /sbin/ldconfig

%postun -n libgvc%{gvc_soversion} -p /sbin/ldconfig

%post -n libgvpr%{gvpr_soversion} -p /sbin/ldconfig

%postun -n libgvpr%{gvpr_soversion} -p /sbin/ldconfig

%post -n libpathplan%{pathplan_soversion} -p /sbin/ldconfig

%postun -n libpathplan%{pathplan_soversion} -p /sbin/ldconfig

%post -n libxdot%{xdot_soversion} -p /sbin/ldconfig

%postun -n libxdot%{xdot_soversion} -p /sbin/ldconfig

%post -n liblab_gamut%{lab_gamut_soversion} -p /sbin/ldconfig

%postun -n liblab_gamut%{lab_gamut_soversion} -p /sbin/ldconfig

%if "%{flavor}" == "qt5"
%files -n graphviz-gvedit
%license epl-v10.txt
%{_bindir}/gvedit
%dir %{_datadir}/%{mname}/gvedit
%{_datadir}/%{mname}/gvedit/attrs.txt
%{_mandir}/man1/gvedit.1%{ext_man}
%endif

%if "%{flavor}" == "addons"
%files -n graphviz-smyrna
%license epl-v10.txt
%{_bindir}/smyrna
%{_datadir}/%{mname}/smyrna
%{_mandir}/man1/smyrna.1%{ext_man}

%files -n graphviz-gd
%{_bindir}/diffimg
%{_mandir}/man1/diffimg.1%{ext_man}
%{_libdir}/graphviz/libgvplugin_gd.so*

%post -n graphviz-gd
%{_bindir}/dot -c

%postun -n graphviz-gd
if test -x %{_bindir}/dot; then rm -f %{_libdir}/graphviz/%{config_file} ; %{_bindir}/dot -c ; fi

%files -n graphviz-gnome
%{_libdir}/graphviz/libgvplugin_gs*
%{_libdir}/graphviz/libgvplugin_rsvg*
%{_libdir}/graphviz/libgvplugin_pango*
%{_libdir}/graphviz/libgvplugin_gtk*
%{_libdir}/graphviz/libgvplugin_xlib*
%{_libdir}/graphviz/libgvplugin_gdk*

%post -n graphviz-gnome
%{_bindir}/dot -c

%postun -n graphviz-gnome
if test -x %{_bindir}/dot; then rm -f %{_libdir}/graphviz/%{config_file} ; %{_bindir}/dot -c ; fi

%files -n graphviz-guile
%{_libdir}/graphviz/guile
%{_mandir}/man3/gv.3guile%{ext_man}

%if %{with java}
%files -n graphviz-java
%{_libdir}/graphviz/java
%{_mandir}/man3/gv.3java%{ext_man}
%endif

%files -n graphviz-lua
%{lua_archdir}/gv.so
%{_mandir}/man3/gv.3lua%{ext_man}

%files -n graphviz-x11
%license epl-v10.txt
%{_bindir}/dotty
%{_bindir}/lefty
%{_bindir}/lneato
%{_datadir}/%{mname}/lefty
%{_mandir}/man1/dotty.1%{ext_man}
%{_mandir}/man1/lefty.1%{ext_man}
%{_mandir}/man1/lneato.1%{ext_man}

%if %{with ocaml}
%files -n graphviz-ocaml
%{_libdir}/graphviz/ocaml
%{_mandir}/man3/gv.3ocaml%{ext_man}
%endif

%files -n graphviz-perl
%{perl_vendorarch}/gv.pm
%{perl_vendorarch}/gv.so
%{_mandir}/man3/gv.3perl%{ext_man}

%files -n graphviz-php
%{phpext_dir}/gv.so
%{_datadir}/php%{php_version}/gv.php
%{_mandir}/man3/gv.3php%{ext_man}
%config(noreplace) %{phpconf_dir}/gv.ini

%files -n python3-gv
%{python3_sitearch}/_gv.so
%{python3_sitearch}/gv.py
%{_mandir}/man3/gv.3python%{ext_man}

%files -n graphviz-ruby
%{rb_vendorarchdir}/gv.so
%{_mandir}/man3/gv.3ruby%{ext_man}

%files -n graphviz-tcl
%dir %{_datadir}/tcl/%{mname}
%{_libdir}/tcl[0-9].[0-9]
%{_libdir}/libgdtclft*
%{_libdir}/libgv_tcl.so
%{_libdir}/libtcldot*
%{_libdir}/libtclplan*
%{_datadir}/tcl/%{mname}/pkgIndex.tcl
%{_mandir}/man3/*.3tcl*

%post -n graphviz-tcl -p /sbin/ldconfig
%postun -n graphviz-tcl -p /sbin/ldconfig

%files -n graphviz-webp
%{_libdir}/graphviz/libgvplugin_webp.so*

%post -n graphviz-webp
%{_bindir}/dot -c

%postun -n graphviz-webp
if test -x %{_bindir}/dot; then %{_bindir}/dot -c ; fi

%files -n graphviz-doc
%docdir %{_defaultdocdir}/%{mname}-doc
%{_defaultdocdir}/%{mname}-doc
%{_datadir}/graphviz/demo

%endif

%if "%{flavor}" == ""
%files
%doc doc/FAQ.html AUTHORS README NEWS ChangeLog
%license epl-v10.txt
%{_bindir}/acyclic
%{_bindir}/bcomps
%{_bindir}/ccomps
%{_bindir}/circo
%{_bindir}/cluster
%{_bindir}/dijkstra
%{_bindir}/dot
%{_bindir}/dot2gxl
%{_bindir}/dot_builtins
%{_bindir}/edgepaint
%{_bindir}/fdp
%{_bindir}/gc
%{_bindir}/gml2gv
%{_bindir}/graphml2gv
%{_bindir}/gv2gml
%{_bindir}/gv2gxl
%{_bindir}/gvcolor
%{_bindir}/gvgen
%{_bindir}/gvmap
%{_bindir}/gvmap.sh
%{_bindir}/gvpack
%{_bindir}/gvpr
%{_bindir}/gxl2dot
%{_bindir}/gxl2gv
%{_bindir}/mm2gv
%{_bindir}/neato
%{_bindir}/nop
%{_bindir}/osage
%{_bindir}/patchwork
%{_bindir}/prune
%{_bindir}/sccmap
%{_bindir}/sfdp
%{_bindir}/tred
%{_bindir}/twopi
%{_bindir}/unflatten
%dir %{_datadir}/%{mname}
%{_datadir}/%{mname}/graphs
%dir %{_datadir}/%{mname}/gvpr
%{_datadir}/%{mname}/gvpr/addranks
%{_datadir}/%{mname}/gvpr/addrings
%{_datadir}/%{mname}/gvpr/anon
%{_datadir}/%{mname}/gvpr/attr
%{_datadir}/%{mname}/gvpr/bb
%{_datadir}/%{mname}/gvpr/bbox
%{_datadir}/%{mname}/gvpr/cliptree
%{_datadir}/%{mname}/gvpr/col
%{_datadir}/%{mname}/gvpr/collapse
%{_datadir}/%{mname}/gvpr/color
%{_datadir}/%{mname}/gvpr/dechain
%{_datadir}/%{mname}/gvpr/deghist
%{_datadir}/%{mname}/gvpr/deledges
%{_datadir}/%{mname}/gvpr/delmulti
%{_datadir}/%{mname}/gvpr/delnodes
%{_datadir}/%{mname}/gvpr/depath
%{_datadir}/%{mname}/gvpr/dijkstra
%{_datadir}/%{mname}/gvpr/flatten
%{_datadir}/%{mname}/gvpr/get-layers-list
%{_datadir}/%{mname}/gvpr/group
%{_datadir}/%{mname}/gvpr/indent
%{_datadir}/%{mname}/gvpr/knbhd
%{_datadir}/%{mname}/gvpr/maxdeg
%{_datadir}/%{mname}/gvpr/path
%{_datadir}/%{mname}/gvpr/rotate
%{_datadir}/%{mname}/gvpr/scale
%{_datadir}/%{mname}/gvpr/scalexy
%{_datadir}/%{mname}/gvpr/span
%{_datadir}/%{mname}/gvpr/topon
%{_datadir}/%{mname}/gvpr/treetoclust
%{_datadir}/%{mname}/gvpr/chkclusters
%{_datadir}/%{mname}/gvpr/cycle
%{_datadir}/%{mname}/gvpr/addedges
%{_datadir}/%{mname}/gvpr/binduce
%{_datadir}/%{mname}/gvpr/bipart
%{_datadir}/%{mname}/gvpr/chkedges
%{_datadir}/%{mname}/gvpr/histogram
%{_mandir}/man1/*.1%{ext_man}
%{_mandir}/man7/*.7%{ext_man}
%exclude %{_mandir}/man1/smyrna.1%{ext_man}

%files -n libcdt%{cdt_soversion}
%{_libdir}/libcdt.so.%{cdt_soversion}*

%files -n libcgraph%{cgraph_soversion}
%{_libdir}/libcgraph.so.%{cgraph_soversion}*

%files -n libgvc%{gvc_soversion}
%{_libdir}/libgvc.so.%{gvc_soversion}*

%files -n libgvpr%{gvpr_soversion}
%{_libdir}/libgvpr.so.%{gvpr_soversion}*

%files -n libpathplan%{pathplan_soversion}
%{_libdir}/libpathplan.so.%{pathplan_soversion}*

%files -n libxdot%{xdot_soversion}
%{_libdir}/libxdot.so.%{xdot_soversion}*

%files -n liblab_gamut%{lab_gamut_soversion}
%{_libdir}/liblab_gamut.so.%{lab_gamut_soversion}*

%files plugins-core
%dir %{_libdir}/%{name}
%ghost %{_libdir}/%{name}/%{config_file}
%{_libdir}/%{name}/*.so*

%files devel
%{_includedir}/graphviz
%{_libdir}/libcdt.so
%{_libdir}/libcgraph.so
%{_libdir}/libgvc.so
%{_libdir}/libgvpr.so
%{_libdir}/liblab_gamut.so
%{_libdir}/libpathplan.so
%{_libdir}/libxdot.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.3%{ext_man}
%endif

%changelog
* Fri Sep  6 2024 Dr. Werner Fink <werner@suse.de>
- For bug boo#1225776 add patches
  * graphviz-2.49.3-boo1225776-gcc14.patch silent warning/error
    on incompatible pointer type
  * graphviz-87cc546.patch
    also fix incompatible pointer type
* Tue Jul  9 2024 Martin Jambor <mjambor@suse.com>
- Add -fpermissive to optflags when compiling the addons flavor in
  order to prevent GCC 14 to throw errors upon encountering various
  C99 violations. [boo#1225776]
* Thu Mar  7 2024 Thomas Renninger <trenn@suse.de>
- VUL-0: CVE-2023-46045: graphviz: out-of-bounds read via a crafted config6a file
  bsc#1219491
  A gvc-detect-plugin-installation-failure-and-display-an-error.patch
- Some alphabetical re-ordering and other spec file changes which should
  not have any functional change which came from some kind of auto-spec
  cleaner
* Thu Feb 22 2024 Michael Vetter <mvetter@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
- Update graphviz-rpmlintrc
* Tue Nov 28 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Require bitstream-vera-fonts for correct .png rendering by doxygen+dot
* Wed Mar  1 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix RPM conditionals for PHP, elif does not work on Leap 15.x
- Remove unused ghostscript_any BuildRequires for qt5 and main
  flavors
* Mon Nov 14 2022 pgajdos@suse.com
- php8 support was added in swig 4.1.0
* Wed Oct 19 2022 Klaus Kämpf <kkaempf@suse.com>
- add swig-4.1.0.patch to work around graphviz's incompatibility
  with swig-4.1.0.
* Fri Aug 12 2022 Stephan Kulow <coolo@suse.com>
- Split the Qt5 dependencies from addons flavor - it's just gvedit
* Mon Jan 10 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove pointless libgraphviz6 subpackage only containing broken
  and unnecessary ld.so.conf.d dropin.
- Add required Provides and Obsoletes for library package split.
- Remove unversioned symlinks for plugins, breaking shared library
  policy.
- Remove duplicate python3 bindings in wrong directory (again).
- Add missing post scriptlet for webp plugin.
- Fix postun scriptlets for all plugins (be silent when graphviz
  gets removed completely, report errors otherwise).
- Cleanup spec file.
- Disable Java bindings, as unused/untested, and packaging
  is quite broken.
* Wed Nov 24 2021 Dirk Müller <dmueller@suse.com>
- update to 2.49.3:
  - gvpr "split", "tokens", and "index" functions produce incorrect results
    This was a regression that occurred between 2.47.1 and 2.47.2.
  - Lefty is disabled by default in the Autotools build system. To re-enable it,
    pass `--enable-lefty` to `./configure`. In a future release, Lefty will be
    removed.
  - remove PHP5 support in SWIG bindings
  - Msys experimental packages are included in release artifacts
  - CMake build system incorrectly aliases gv2gml to gml2gv
  - Gv2gml Doesn't escape quotes in attributes
  - GVPR incorrectly understands color schemes
- reenable lefty to fix addons build
* Wed Oct 27 2021 Christian Vögl <christian.voegl@suse.com>
- Split libgraphviz into tlibcdt, libcgraph, libgvc, libgvpr, libpathplan,
  libxdot, and  liblab_gamut packages, in order to fix shlib naming policy
  errors (boo#1191756)
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 2.49.1:
  - the CMake build system installs gzipped man pages if `gzip` is available #1883
  - CMake projects using Graphviz as a subproject (`add_subdirectory`) can now
    link against and use `gvc`.
  - various problems in the generation of Javascript bindings
  - 2.48.0: test suite is failing #2112
  - Ensure correct file-level dependency for generated file in cmake generated
    projects #2119
  - compile failures with a C++20-compatible toolchain #2122
  - compile errors on macOS when using Bison 3.8 #2127
  - Make Graphviz buildable as a cmake subproject/subdirectory #1477
  - Header not found in Cmake project #2109
  - a very basic C++ API for a subset of the functions in lib/cgraph and
    lib/gvc, allowing a graph to be rendered from DOT source to a
    specified format. The new API is available through two new
    libraries: lib/cgraph++ and lib/gvc++. It is experimental, meaning
    that it might have breaking changes also in upcoming patch or minor
    releases (towards #2001)
  - CMake builds now support an `with_expat` option that allows the support for
    using HTML-like labels through the optional expat library to be explicitly
    enabled (default) or disabled
  - CMake builds now support an with_zlib option that allows the support for
    raster image compression through the optional zlib library to be explicitly
    enabled (default) or disabled
  - the CMake build system now enables `-Wextra` when building C++
  - some Cgraph functions that take `char*` arguments that they do not modify have
    been updated to take `const char*` arguments #634
  - incorrectly using the `layout` attribute on anything other than a graph now
    results in a warning about this being invalid #2078
  - `edgepaint` accepts more standard `--` prefixed command line arguments and
    rejects invalid options #1971
  - improved detection of Lefty dependencies in the Autotools build system
  - libexpr rejects printing the time (`%%t`) if no format is provided
  - `-DDATE=…` option in the CMake build system has been removed
  - the Autotools build system no longer writes the DATE file and the portable
    source tarball no longer includes this
  - The attached dot file causes a segfault when processed #2095
  - fix typos and update URLs in `edgepaint` usage text and man page
  - Fix clang's undefined behavior warning in dotLayout
  - gvpr doesn't build on macOS but MKDEFS_EXECUTABLE points to wrong
    directory #2101
  - the generated gdefs.h header is no longer installed
  - `ccomps` out-of-memory message no longer incorrectly refers to `gc`
  - do not abort when `calloc(0, x)` or `calloc(x, 0)` in `gcalloc` return `NULL`
  - failed Exshort_t type discrimination #1799
  - dot manpage is in wrong directory on Windows #1936
  - CMake builds fail when when the ltdl library is not available even if the
    `enable_ltdl` option is `ON`
  - CMake builds fail when when the optional `zlib` library is not available
  - fix graph rotation in quartz plugin
* Mon Sep  6 2021 Christian Voegl <christian.voegl@suse.com>
- Changelog Update for SLES:
  The following patch has been backported to SLES and is therefore
  missing from the Factory changelog:
  * graphviz-malformed_input.patch (boo#1132091)
* Mon Aug 30 2021 Christian Vögl <christian.voegl@suse.com>
- Changelog Update for SLES:
  The Following patches have been backported to SLES and are therefore
  missing from the Factory changelog:
  * graphviz-2.40.1-fix-dot-segfault.patch (bsc#1151207)
  * graphviz-out-of-bounds-write.patch (bsc#1185833)
  * graphviz-null_dereference.patch (bsc#1185833)
* Wed Aug 11 2021 Christian Vögl <christian.voegl@suse.com>
- Dropped python2 subpackages as the bindings are removed in 2.48
- Update to version 2.48.0 (changes since 2.47.1)
  * marginally more accurate computations in Smyrna sphere projection
  * Perl is no longer required to build Graphviz #2067
  * nop more reliably returns success and failure exit statuses
  * implicit 63 character limit on plugin names is removed in GVC
  * remove Python 2 bindings #1992
  * improved thread-safety in Graphviz bindings Makefile
  * the CMake build system now enables -Wextra when building C++
  * some Cgraph functions that take char* arguments that they do not modify have
    been updated to take const char* arguments #634
  * incorrectly using the layout attribute on anything other than a graph now
    results in a warning about this being invalid #2078
  * edgepaint accepts more standard -- prefixed command line arguments and
    rejects invalid options #1971
  * improved detection of Lefty dependencies in the Autotools build system
  * Fix: out of bounds read when attempting to load a plugin whose name is ≥63 characters
  * Fix: out of bounds read when examining a registered plugin whose name is ≥63 characters
  * Fix: do not fclose(NULL) in gvmap
  * Fix: Uninitialized variable read in delaunay_tri
    potentially mismatched format string in tclpkg
  * Fix: ortho's eqEndSeg incorrectly modifies its arguments #2047
  * Fix: Autotools enables -Wtrampolines and -Wlogical-op for Clang #2066
  * Fix: node_distinct_coloring failure due to out-of-memory now reported correctly
    instead of referring to a failure to open lab_gamut
  * Fix: a typo GD_LIBS to GDLIB_LIBS in tclpkg/tcldot/Makefile.am !2022
  * Fix: Autotools build system sets libgd variables now instead of incorrectly setting
    GTK variables
  * Fix: HTML strings used as labels are distinguishable in GXL output by kind="HTML-like string"
  * Fix: a Bashism removed from the Autotools build system
  * Fix: when Criterion is available, the command_line test binary is no longer built
    and installed by default, but rather during make check
  * Fix: round-tripping a file through gv2gxl and then gxl2gv no longer causes
    HTML-like labels to become non-HTML like labels #517
  * Fix: fix ODR violation by including the ortho object files in the gvc lib also for
    CMake and MSbuild #2096
* Mon Jun 28 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update graphviz-2.20.2-interpreter_names.patch so the Python demo
  uses Python 3.
* Wed Jun  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Install epl-v10.txt instead of COPYING.
  The COPYING file is a symlink to epl-v10.txt.
* Fri May 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.47.1
  * More detailed error messages when opening input file fails
  * The edges in JSON output are ordered now
  * Fixed xdot man page does not document some functions
  * Fixed PIC renderer
  * Fixed dot conversion to dia format
  * Fixed memory leak of reference-counted HTML strings
  * Fix for TBbalance attribute code
  * Fixed HTML parser error with single closing square bracket in
    table row
  * Fixed reference counted strings put the HTML bit in the middle
    of the reference count
  * Fixed &amp; escape disappearing
  * Fixed gvpr -? to actually print usage and exit non-zero
  * Fixed memory leak in libmingle
  * Fixed memory leak in ANN bridge
  * Fixed buffer overflow in unflatten
  * Fixed agxbputc macro does not bracket its arguments
- Drop upstream fixed graphviz-2.46-fix-shebang.patch
  * Using POSIX shell, no need for ksh
* Wed Apr 14 2021 Andreas Schwab <schwab@suse.de>
- Remove obsolete pre_checkin.sh
* Thu Apr  8 2021 Christian Vögl <christian.voegl@suse.com>
- Buildrequire full ghostscript in the addons package
  to avoid a conflict betwen ghostcript-mini and ghostscript-devel
* Tue Mar 16 2021 Christian Vögl <christian.voegl@suse.com>
- Replace ghostscript-mini dependency with ghostscript_any
* Mon Mar  1 2021 Christian Vögl <christian.voegl@suse.com>
- Add graphviz-webp package to for webp image support
* Tue Feb 23 2021 Christian Vögl <christian.voegl@suse.com>
- Reenable ghostscript, but require just ghostscript-mini
* Thu Feb 18 2021 Christian Vögl <christian.voegl@suse.com>
- Update to new release 2.46.1 (changes since 2.44.1)
  * Support for building against Guile 2.2
  * Portable source is now also offered as a .tar.xz
  * CentOS/RHEL 6 is no longer supported
  * Vestiges of Qt4 support have been removed
  * C++11 support is now required of the C++ compiler used to build Graphviz
  * C99 support is now required of the C compiler used to build Graphviz
  * Question about userout() function in agerror.c #1924
  * The minimum version of Python required to run the test suite is 3.6
  * memory leak in label construction
  * gvedit compilation errors out, but works if manually compiled with qt5 #1862
  * incorrect HTML BR attribute parsing code #1913
  * broken overflow checks in RectArea #1906
  * various memory leaks !1699
  * Fix bad free in lefty !1709
  * typo in pathcross #1926
  * Out-of-bounds write caused by incorrect error handling of malloc in genUserdata #1928
  * Offer .tar.xz files too #454
  * Header file graphviz_version.h has no include guards #1929
  * regression: newlines embedded in quoted labels / node names are not preserved in 2.46.0 #1931
  * Properly fill graphviz_version.h !1706
  * Cgraph's agxbuf API gained a new function agxbdisown(), for dissociating
  * backing memory from the managed buffer
  * Build system support for the Elbrus 2000 CPU, thanks to Michael Shigorin
  * Cgraph's agheap() API has been removed
  * Autotools build system support for eFence has been removed
  * Building Graphviz with ICC defaults to -O2 instead of -O0
  * Build system work arounds for GCC 3 have been removed
  * Incomplete support for running the test suite under CMake has been removed
  * Portable source tarballs now use the “ustar” POSIX format
  * Minimum version of Flex required to build Graphviz is now 2.5.2
  * Minimum version of Bison required to build Graphviz is now 3.0
  * Minimum version of CMake required to build Graphviz using CMake is now 3.1
  * gvpr: line numbers in gvpr errors/warnings are incorrect #1594
  * URL typo in patchwork man page
  * Escaped backslashes are not correctly handled when producing xdot with dot #165
  * heap-over-flow(off-by-null) in lib/common/shapes.c #1700
  * Windows MSBuild executables have the wrong version #1745
  * Cast Overflow at pango_textlayout #1314
  * x11 back end segfaults if display is unavailable #1776
  * typo in cmd/gvpr/lib/clustg #1781
  * Segfault in dot #1783
  * Incorrect 'Arrow type "s" unknown' error #1444
  * segfault on reading 0x10 #1724
  * Null-dereference READ (144736912) #1676
  * "Warning! PATH too long installer unable to modify PATH!" using CMake Windows installer and PATH length > 1024 #1770
  * gvedit -? gives "option - unrecognized - ignored" instead of showing usage #1813
  * lefty is not built for Windows (fixed for MSBuild builds only) #1818
  * a failure to detect OpenGL glGenTextures() errors has been corrected
  * sfio does compile time benchmarknig #1422
  * iffe "lib" check always succeeds when compiler optimises #1521
  * syntax error near text who is not present #1411
  * Explicitly links with libstdc++; should allow libc++ if appropriate #163
  * A macOS file that was erroneously excluded from portable source tarballs has
  * been restored
  * Add option -? for usage to diffimg
  * Add option -? for usage to dotty
  * Add option -? for usage to lneato
  * Add option -? for usage to vimdot
  * Fix smyrna -? to actually print usage instead of error
  * Fix edgepaint -? to actually print usage instead of error
  * Remove '"' from usage text in non-Windows version of dotty
  * Correct misspelled 'smyrna' in usage
  * Fix edgepaint -o option
  * Correct shebang of gvmap.sh to use ksh
  * Fix gvmap.sh -? option to exit with zero exit status
  * Graphviz doesn't build on MacOS with the latest libc++ #1785
  * make fails if ps2pdf is not installed (using autotools) #1763
  * multiple graphs to file output causes a segfault #1845
  * lefty PTY functionality relies on file descriptor implementation details #1823
  * buffer overflow in fdpgen
  * Crashes by VRML output when current directory is not writable #793
  * Segmentation fault when newrank=true #1221
  * sfdp craches #236
  * fdp segmentation fault with GK=0 #1290
  * fdp crash #1865
  * Graphviz always crash with this simple dot file #167
  * Seg fault in dot #1771
  * gml2gv doesn't handle some attributes correctly #1869
  * Add missing circo, fdp, neato, osage, patchwork, sfdp & twopi tools to Windows builds (copies of dot)
  * Add gv2gml tool to CMake (copy of gml2gv on Windows, symlink to gml2gv otherwise)
  * Regression: fdp generates internal names in the output #1876
  * Regression: fdp assertion error on cluster in edge #1877
  * Regression in id / &lt;title&gt; in svg for twopi #1907
- graphviz-2.46-fix-shebang.patch added to make rpmlint happy
- graphviz-no_strict_aliasing.patch changed to be applicable to current files
- configure without ghostscript to break new build cycle
- Update source URLs
* Thu Dec 31 2020 Arjen de Korte <suse+build@de-korte.org>
- Use _multibuild to build graphviz and graphviz-addons in a single
  development project
  - graphviz-addons.changes
  - graphviz-addons.spec
* Thu Dec 31 2020 Arjen de Korte <suse+build@de-korte.org>
- Update to new release 2.44.1 (changes since 2.42.3)
  * applied RH patches (from graphviz-2.42.2-8.fc32.src.rpm)
  * some allocation failures that could previously allow memory
    corruption now exit
  * lab_gamut.3.pdf is no longer included in release archives
  * Fixed Neato's hier mode is broken since v2.44.0
  * Fixed segmentation fault (core dumped)
  * New SGD mode in neato
  * Add pkg-config files
  * tred: add feature to output removed edges to stderr upon request
  * Workaround: avoid creating a virtual edge loop.
  * Add riscv64 to host_cpu configure.ac
  * lib/cgraph: include empty malloc.h from subdir include
  * lib/gvpr: compile mkdefs with $(HOSTCC) rather than $(CC)
  * lib/vpsc: rename bcopy->b_copy
  * Fixed the NativeCodeAnalysis task failed unexpectedly.
  * Include all test files in distro
  * host_cpu add mips64 platform
  * Correct description of 'port' syntax in manual
  * svg output displays TITLE of %%3 if graph had no name
  * XML errors in generated SVG when URL attribute contains
    ampersand (&)
  * Test files missing from source distributions
  * SVG error for "g.transform.scale " in graphviz version 2.43
- BuildRequires for ghostscript and groff (generate cdt documentation)
- Extension graphviz-php changes:
  * Require php(api) and php(zend-abi) to guarantee ABI compatibility
  * Don't pull in extra libraries from PHP
    + graphviz-no_php_extra_libs.patch
  * Remove argon2-devel from list of dependencies
  * Automatically enable extension when installed by providing
    /etc/php{5,7}/conf.d/gv.ini
* Tue Mar 31 2020 Tomáš Chvátal <tchvatal@suse.com>
- Rename python*-graphviz to python*-gv, there is also normal
  pypi graphviz package and we clash otherwise and override
  each other
* Fri Mar 27 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add also configure option to not build py2 if the python2
  build is disabled
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add python2/python3 split subpkgs in order to allow building
  without python2 available
* Thu Mar  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Auto-identify the correct ruby-version using pkg-config.
* Mon Jan 13 2020 Christian Vögl <cvoegl@suse.de>
- Update to new release 2.42.3
  - tidy gvedit about dialog strings
  - check for mmap failure in plugin code
  - fix broken symlinks to _gv.so with Python
  - fix out of source build with LIBGD
  - some minor bugfixes
- Fix changelog of last update:
  - Accidentally had both CVE entries mashed together.
* Wed Sep  4 2019 Christian Vögl <christian.voegl@suse.com>
- Switch from github master to new release 2.42.1
  - Fixes CVE-2019-11023 (bsc#1132091)
  - Fixes CVE-2018-10196 (bsc#1093447)
  - Fixes quite a few bugs
- Removed graphviz-fix-ruby-version.patch (fixed in upstream)
* Thu May  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Tweak runtime Requires(post): graphviz to same or newer version.
  Needed after change to git checkout instead of released tarballs.
* Tue Apr 16 2019 Christian Vögl <christian.voegl@suse.com>
- Disabled Visio plugin
* Mon Apr 15 2019 Atri Bhattacharya <badshah400@gmail.com>
- Use %%%%python3_sitearch macro to package python3 modules.
- use correct ruby version (2.5) for openSUSE 15.1 and earlier.
* Tue Apr  2 2019 Christian Vögl <christian.voegl@suse.com>
- Now using master branch of upstream, as there have been no releases for
  over two years
  * this should fix CVE-2019-11023 (boo#1132091)
- Removed  graphviz-qt5.patch (now in upstream)
- Removed reproducible.patch (now in upstream)
- graphviz-smyrna-link_against_glu.patch changed to be applicable to current files
- graphviz-no_strict_aliasing.patch changed to be applicable to current files
- Added graphviz-fix-ruby-version.patch to remove hardcoded dependency on ruby 1.9
- graphviz.spec updated for new version
- created _service file
* Fri Nov 30 2018 jbrielmaier@suse.de
- use pkg-config with correct parameter, reported by Werner Fink
* Thu Nov 29 2018 jbrielmaier@suse.de
- Support dynamic move to Guile 2.2, part of boo#1117121:
  - Replace conditional pkgconfig(guile-2.[02]) BuildRequires with
    guile-devel: The package name is unchanged, which allows the
    distro projects to move wihout step-locking changes.
  - Patch configure.ac to look for guile-2.2 if guile 2.2 is being
    used.
- order inputs alphabetically
* Fri Nov 16 2018 trenn@suse.de
- Fixed double file declaration in graphviz and graphviz-addons (x11)
- Mark license files with %%license instead of %%doc
* Thu Oct 25 2018 trenn@suse.de
- Build with gts support (bsc#1108978, bsc#1108976)
  SLE12 flavors do not provide gts, so explicitly exclude
  gts support there.
* Mon Jul 30 2018 bwiedemann@suse.com
- Extend reproducible.patch to make build reproducible (boo#1041534)
* Tue Mar 27 2018 stefan.bruens@rwth-aachen.de
- Build with PHP5 for Leap 42.x and earlier, PHP7 requires swig 3.0.11
  Drop graphviz-plugins-fix_install_dirs.patch, use sed script to
  fix directories, same as for Lua
* Tue Mar 27 2018 stefan.bruens@rwth-aachen.de
- Do not delete dotty/lefty/lneato man pages which are part of
  the x11 subpackage, built from the addons package/spec.
  (No changelog entry).
* Sat Feb 10 2018 stefan.bruens@rwth-aachen.de
- Drop harmful modification of tclpkg/gv/gv_doc_langs.tcl, which
  changes the timestamp, although the file does not contain LIB_DIR.
  Graphviz ships prebuilt manpages in man and PDF format. Modifying
  the tcl script rebuilt the documentation, and replaced the PDFs
  with empty documents (due to missing groff). This also made the
  doc subpackage nonreproducible, causing rebuilds in all dependent
  packages.
* Thu Feb  8 2018 stefan.bruens@rwth-aachen.de
- Disable guile 2.2 modifications temporarily
- Move lefty/dotty/lneato graph editor tools to x11 subpackage and
  build as part of addons package. Removes any X11 dependency from
  core package, both build and runtime.
- Drop unused libXaw6 build dependency
- move libpng, libjpeg, freetype and fontconfig build dependencies
  to addons, unused for core
* Thu Jan 25 2018 dimstar@opensuse.org
- Move to pkgconfig(guile-2.2) BuildRequires on suse_version >=
  1500.
* Tue Jan 16 2018 dimstar@opensuse.org
- Disable building the graphviz-ocaml package: we have no consumer
  of it, but not building it allows us to elminiate a build cycle.
* Thu Oct 26 2017 pth@suse.de
- Reverse last change.
* Wed Oct 25 2017 pth@suse.de
- Remove pre_checkin.sh and graphviz-addon.* as they aren't needed
  anymore.
* Mon Oct 23 2017 pth@suse.de
- Replace the recommends for graphviz-gnome by a 'supplements packageand'
  so that graphviz doesn't pull in all the X11 related stuff on a
  machine without graphical desktop (bsc#930442).
* Wed Oct  4 2017 dimstar@opensuse.org
- Exclude %%{_mandir}/man1/smyrna.1%%{ext_man} from graphiz' main
  package, since the man page is packaged in the -smyrna sub
  package already.
* Mon Aug  7 2017 tchvatal@suse.com
- Add bcond for java and ocaml that can be overriden in staging prj
* Thu Aug  3 2017 tchvatal@suse.com
- Drop smyrna and gvedit separate spec, now handled by
  graphviz-addons
  * Switch graphviz-gvedit to Qt5:
    + graphviz-qt5.patch
- Drop graphviz-plugin subkpg in favor of graphviz-addons.spec
  that is generated from graphviz directly
- Make sure all patches are applied also in main package so none
  get lost by accident
- Refresh patch graphviz-plugins-fix_install_dirs.patch
- Make sure graphviz php plugins are generated using php7
  * set the php7 path in graphviz-plugins-fix_install_dirs.patch
- Remove tkspline from tcl package as it is no longer shipped
- Make sure the pic/pie is enforced on all the libs/bins
* Wed Aug  2 2017 tchvatal@suse.com
- Update to 2.40.1 release:
  * Remove usage of ast_common.h
  * network-simplex fixes and optimization (Stephen North)
  * built-in tred tool now available in the various swig generated
    language bindings (John Ellson)
  * number rounding added to SVG renderer (same as PS and TK rounding)
    to aid regression testing. (John Ellson)
  * additional regressson test framework, used in Travis CI builds. (Erwin Janssen)
  * PHP7 support (requires swig-3.0.11 or later). (John Ellson)
  * Allow user to specify clustering algorithm in gvmap. (Emden Gansner)
  * Add Sierpinski graph generator to gvgen. (Emden Gansner)
  * Extensive code cleanup (Erwin Janssen)
  * Removal of libgd source - use vanilla libgd from separate install
  * Windows builds (Erwin Janssen)
  * Appveyor CI for automated Windows build testing (Erwin Janssen)
  * Travis CI for Fedora/Centos builds (Erwin Janssen)
  * Added JSON output format, -Tjson  (Emden Gansner)
  * New curved arrowhead, cylinder node shape.
  * Resolves bugs: 2599, 1172
  * Add cylinder shape for databases.
  * Free installed plugins
  * Update makefile for dot so that the using libpanco_C in the static build include PANGOFT2
    as well as PANGOCAIRO_LIBS (needed for some versions of Ubuntu)
  * Add json output format
  * output class value in svg files
  * Add plain shape for use with HTML-like labels.
  * Add icurve arrowhead.
  * Revert to old, translate to origin semantics in neato, etc. Add flag notranslate if that is
    what the user desires.
- Run over with spec-cleaner and convert deps to pkgconfig
- Fix Group
- Remove unused pre requirements as there is no pre phase
- Inline sed changes and do not rely on pipes
- Do not add needless requires to devel pkg, there are no such stated
  dependencies in any of the .pc files provided
- Add pre_checkin.sh scriptlet to allow generating of the extras subpkg
  instead of having independent spec files
* Sun May 28 2017 bwiedemann@suse.com
- Add reproducible.patch to not have binaries depend on build system timings
* Wed Jun 10 2015 mpluskal@suse.com
- Remove pangocairo and lasi support as it introduces build cycle
* Thu Apr  9 2015 opensuse.lietuviu.kalba@gmail.com
- Build with pangocairo and lasi support.
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix ksh-specific constrictions in gvmap.sh script
- add patches:
  + graphviz-2.38.0-fix-gvmap.patch
* Tue Jul 15 2014 toddrme2178@gmail.com
- Remove upstream-included patch graphviz-ppc64le_lib64_support.patch
  from graphviz-plugins.spec
* Fri May 23 2014 pth@suse.de
- Fix URL to point to the new location of the sources.
* Fri May 23 2014 pth@suse.de
- Update to 2.38.0. Changes since 2.36.0:
  - Resolve bugs: 2409, 2413, 2417, 2420, 2422, 2423, 2425
  - Enable packing for dot
  - Allow scaling to work for all non-dot layouts
  - Add overline text characteristic.
  - Fix bugs in gvpr and gv.cpp so edges can be created in subgraphs.
  - Add edgepaint program for coloring edges to make them easier to
    tell apart.
  - Modify neato to avoid unnecessary translations of output. This
    allows positions given on input to remain the same on output.
  - Fix swig java package to work and support gv.renderresult.
  - Fix test for the absence of layout (old test relied on statically
    allocated Agraphinfo_t).
  - HTML-like tables and cells can now specify which borders should be drawn.
  - The fixedsize attribute now takes the value "shape" which allows
    labels much larger than the node shape.
- Remove graphviz-fix-includes.patch as the fix has been done
  upstream.
- Add graphviz-array_overflow.patch to fix an off-by-one error.
* Tue Feb  4 2014 pth@suse.de
- Update to 2.36,0:
  (graphviz tracker lives at http://www.graphviz.org/mantisbt/my_view_page.php)
  Fixed bugs:
  * The xdot pad attribute is documented to have a default value of
    0.0555 (inches, equals 0002091:0000004 points).  However when no
    pad attribute was specified, xdot output behaved as though the
    default was 0 (graphviz tracker 2372).
  * Graphviz gave incorrect svg when labels contained HTML entities
    (graphviz tracker 2384).
  * Building gvedit failed with undefined references (graphviz
    tracker 2388).
  * Document that edge[style=tapered] does not support colorList and
    that edge[style=tapered] does not work with arrowType:none
    (graphviz tracker 2391).
  * Use a stronger test for orthogonal routing and, if it fails, revert
    to line segments for edges (graphviz tracker 2393).
  * Fix xdot background polygon coordinates being "nan" with no nodes
    (graphviz tracker 2393).
  * Circo couldn't rescale a graph using the mindist attribute
    (graphviz tracker 2395).
  - Remove old libgraph sources from distributions.
  - Move master git repo to github.com
  September 15, 2013
  - Add <S> element for strike-through to HTML-like labels.
  - This version also fixes the security bugs reported in january.
* Tue Feb  4 2014 pth@suse.de
- Change license to EPL-1.0. Remove contrib/gprof2dot.awk as it
  contains a non-working uri.
* Wed Dec 11 2013 matz@suse.de
- graphviz-fix-includes.patch: Use #include "cgraph.h", not <cgraph.h>
  in graphviz/types.h.
* Tue Oct 29 2013 pth@suse.de
- Add graphviz-getaddrinfo.patch to use getaddrinfo instead of
  gethostbyname.
* Wed Oct 23 2013 pth@suse.de
- Split off smyrna into its own package and spec to eliminate the
  dependency cycle for graphiz.
* Mon Oct 14 2013 pth@suse.de
- Remove gvedit files from filelist in grapfviz.spec.
- Remove build requirement for libqt4.
* Thu Sep 12 2013 pth@suse.de
- Add graphviz-python3_version.patch that put the call to print in
  Parentheses.
* Wed Sep 11 2013 pth@suse.de
- Split off gvedit to it's own spec to avoid circular dependency
  for graphviz and its sup packages.
- Add graphviz-type_punning.patch which compiles the vmalloc sources
  with -fno-strict-aliasing.
* Mon Sep  9 2013 pth@suse.de
- Update to 2.34.0:
  - Resolved bugs:
  * graphviz will hangs if only one point and attribute given (gvz#2326)
  * Inconsistent text position in xdot with HTML-like label (gvz#2333)
  * Graphviz createsedges not asked for, with rank=same (gvz#2334)
  * Graph padding rectangle too big (gvz#2337)
  * labelloc has no effect for HTML-like labels with formatting (gvz#2338)
  * Global search and replace operation in the documentation seems to
    have gone awry (gvz#2340)
  * Rotated graph not quite centered (gvz#2343)
  * When arrowType is list and contains none all subsequent
    arrowTypes are dropped (gvz#2345)
  * arrowType none when included as a multiple arrowtype fails to
    render empty space (gvz#2346)
  * Buffer overflow in lib/common/shapes.c(round_corners) (gvz#2349).
  * Add aarch64 to the architectures using lib64 (gvz#2350)
  * Ask guile-config for includes and libraries (gvz#2351).
  * If string.h present, don't declare memcmp and strcmp (gvz#2352).
  * Include ast_common.h in cdt sources (gvz#2353)
  * Alternative way to get python's version (gvz#2354)
  * Unportable test(1) construct in configure script (gvz#2357)
  * Use parantheses around qw() call in loop (gvz#2359)
  * Saving in Vimdot can crash the graphical window (rh#847458).
  - Added mingle command and library for edge bundling
- Removed Patches that where accepted upstream:
  graphviz-missing_headers.patch
  graphviz-aarch64_lib64_support.patch
  graphviz-type_punning.patch
  graphviz-buffer_overflow.patch
  graphviz-proper_prototypes.patch
* Tue Sep  3 2013 pth@suse.de
- Update to 2.32.0. Changes since 2.28.0:
  2.32.0:
  - New version of xdot format, annotating gradient color schemes
  - Support for reading pdf images using poppler
  - Lefty/dotty/lneato now accept anonymous graphs
  - Add star node shape
  - Add two-tone (non-gradient) fill
  2.30.1:
  - various build fixes
  2.30.0:
  - Replaced libgraph with libcgraph; use of libgraph is now deprecated
  - New ranking algorithm that allows multiple subgraph constraints
  - Support edges using curved arcs.
  - Added new shapes used by the synthetic biology community.
  - For HTML-like labels, provide rounded cells, and dashed or dotted borders.
  - Add lcurve and rcurve arrowheads.
  - Add prototype pie chart and striped fills.
  - Support insets in treemaps to make containment clear
  - Add random rooted tree generation to gvgen
  - Allow GVPRPATH to specify that the default path be prepended or
    appended to it.
  - Support arbitrary lists of layers; allow the user to specify arbitrary
    layers for output.
  - A collection of gvpr scripts, which were part of the source package,
    are now installed in <prefix>/share/graphviz/gvpr, and the that path
    is used as part of th default built-in path for gvpr.
  - Update libexpr to reflect Glenn Fowler's changes including scopes for
    variables.
  - Add next graph variable to gvpr
  - Modify dot and fdp so that a cluster's margin attribute will affect
    the space between the bounding box and nodes
  - Modify the dijkstra tool to use only directed edges
  - Output numbers without quotes if quotes are not needed on input
  - Support gradient fill
  - Provide support for webp images
  - Fix tapered edges to use the dir attribute and arrowhead
  - Add imagepath attribute
  - Add help functionality to Graphviz.app
  - Add <B>,<I>,<U> to html strings via svg
  - Add tapered edges
  - Add support for external labels
  - Add initial implementation of graphml2gv
  - Add basic horizontal and vertical rules to html tables
- Remove graphviz-gd_png_check_sig.patch as the file to patch doesn't
  exist anymore.
- Add graphviz-buffer_overflow.patch to fix a buffer ovderflow in
  lib/common/shapes.c(round_corners) by increasing the number of
  elements in the array.
- Add graphviz-proper_prototypes.patch that changes dthdr.h to
  include ast_common.h to get __STD_C defined, which in turn
  enables proper prototypes.
- Run autoreconf to use -fno-strict-aliasing for libvmalloc sources
- Add patch tags in the spec files
- Upstreamed all patches that aren't SUSE specific.
* Thu Mar 28 2013 pth@suse.de
- Rename aarch64-lib64-support.diff to graphviz-aarch64_lib64_support.patch.
- Add graphviz-type_punning.patch to compile the code in lib/vmalloc
  with -fno-strict-aliasing as it does type punning.
* Sat Mar 16 2013 dmueller@suse.com
- add aarch64-lib64-support.diff:
  * add aarch64 to the list of lib64 architectures
* Wed Jan 16 2013 pth@suse.de
- Add BuildRequires for libXaw which isn't pulled in by x11 anymore
  (bnc#797258).
* Mon Jun 25 2012 coolo@suse.com
- do not buildrequire the whole X stuff but only the libs required
* Tue Oct  4 2011 pth@suse.de
- Rename and prefix patch for uniformity within the package.
* Mon Oct  3 2011 coolo@suse.com
- fix compilation of yast2-qt-graph
* Mon Oct  3 2011 coolo@suse.com
- disable GD plugin completely
* Wed Sep 28 2011 idonmez@suse.com
- Update to version 2.28.0
  - incremented library api version:
    libcdt, libgraph, libcgraph, libgvpr, libgvc
  - Add gvmap, cluster and gvmap.sh
  - Deprecate dotty; prefer gvedit
  - Add patchwork supporting squarified tree maps
  - Add ordering as a node attribute
  - Fix problems with font resolution
  - Fix problems with text placement
  - Fix twopi to set root attribute
  - Make available layouts and formats available via the API
  - Fix error message system so that an application can capture the messages
  - New attributes and features for sfdp
  - gvgen now allows the user to specify graph name and node name template
  - Make overlap=false denote overlap=prism
  - More efficient xdot library
  - HTML-like labels provide ID
  - Fixed bugs: 1480 1980 2044 2087 2088 2089 2091 2093 2094
    2095 2101 2102 2103 2104 2112 2113 2118 2128 2129 2139 2149
    2157 2113 2159 2160 2161 2163
  - Add scale attribute to twopi
  - Add <B>,<I>,<U> to html strings
  - migrated to 2005 version of cdt
* Fri Mar 11 2011 coolo@novell.com
- fix conflict with libltdl (http://bugs.gentoo.org/339298)
* Fri Jun 18 2010 coolo@novell.com
- fix typo
* Fri Jun 11 2010 pth@suse.de
- Fix cut&paste error.
- Plugin configuration file is now named config6 so adapt spec file
  (bnc#607114).
* Tue Jun  1 2010 pth@suse.de
- Fix array underflow in lib/gvpr/compile.c
  (graphviz-wrong_index.patch).
- Mention in description that graphviz-gnome is needed for png
  output.
* Mon May 17 2010 coolo@novell.com
- remove ksh from build requires - no longer needed
* Sun Apr  4 2010 ro@suse.de
- fix build of gd library with new libpng14
  (should use system gd lib ?)
* Tue Mar 16 2010 ro@suse.de
- update to 2.26.3
  - libcgraph.so   version bumped from 4 to 5 due to API changes
  - Allow ranksep to specify multiple radial differences in twopi
  - Allow the user to specify all pairwise distances in neato with
  - added: "smyrna" - a new opengl-based viewer for large graphs
  - added: rudimentary "gml2gv", "gv2gml" converters
  - extended support for various image formats in node images
  - removed vestiges of codegens, now all putput formats supported
    through plugins.  Dropped some output formats for which
    plugins have not been developed: -Tdia, -Tmif
  - gvpr converted to a library; additional array handling and
    text processing functions added; language extended to allow
    multiple BEG_G/N/E blocks.
  - allow background images specified via xdot
  - add new layout engine for large graphs: sfdp
  - add new layout engine for nested graphs: osage
  - fix for buffer overflow (present in 2.22.0 and 2.22.1)
  - libgvc api changed, version bumped.  Affects third party
    applications using libgvc.
  - plugin api changed, version bumped.  Affects third party
    plugins for graphviz.
  - 90%% conversion to cgraph has been done, but not enabled yet,
    (and yes, its true what they say about the last 10%% )
  - drop libagraph from distribution  (use libcgraph)
  - layout code completely converted to floating point.
  - new "dot -P" option for generating a graph of available
    plugins.
  - registered MIME type:  text/vnd.graphviz for .gv files
  - rename files from .dot to .gv to avoid conflict with
    Word templates.  .dot still supported, but deprecated.
  - new command: mm2gv   (matrix-market graph file conversion)
  - rename commands:      dot2gxl -> gv2gxl
  gxl2dot -> gxl2gv
  - new rsvg plugin for support of node shapes in SVG format
  - new gs plugin for support of node shapes in PS format
  - new lasi plugin for support of UTF-8 characters in PS output
    (the above thee plugins are Linux only, at the moment)
  - new quartz plugin (MacOSx only)
  - new gdiplus plugin (Windows only)
  - new -Tvml support in core plugin (thanks Steve Roush)
  - new -Ttk support in core plugin (also used by Tcldot and
    gv_tcl language bindings.)
  - disabled old style codegens completely
* Tue Dec 15 2009 jengelh@medozas.de
- enable parallel building
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Fri Oct 24 2008 mrueckert@suse.de
- fix build with newer libtool
- fix requires of debug package
* Mon Oct 13 2008 pth@suse.de
- Fix vulnerability that allowed overflowing gstack (bnc#433747)
* Thu Jul 10 2008 pth@suse.de
- Update to 2.20.2. Changes since 2.18:
  2.20.2:
  - Fix bug in HTML-like labels
  2.20.1:
  - Fix bug in ccomps related to conversion to cgraph
  2.20.0:
  - Fixed bugs (see http://www.graphviz.org/bugs/buglist.html for
    details:
  - 1315: Different/error output for *.os and *.pdf
  - 1317: Graphviz fails to open more than 512 files.
  - 1324: Graphviz crashes in atexit().
  - 1336: Plain format label delimiters change randomly.
  - 1343: Layouts other than 'dot' seem broken in tcldot due to
    documentation error.
  - 1364: Dot fails with failed assertion.
  - Add new "folder" shape for nodes.
  - Migration of gvpr tools to libcgraph.
  - New output format -Teps  (encapsulated postscript)
  - Various NetBSD and SuSE fixes incorporated
  - ./configure now provides a summary
* Sun Apr 27 2008 coolo@suse.de
- fix build
* Tue Apr 22 2008 pth@suse.de
- Move all GTK/GNOME related stuff to plugins package.
* Tue Apr 15 2008 pth@suse.de
- Readd plugins left out by accident.
- Add upstream patch that makes 'dot -c' completely verifiy all
  cross-plugin dependencies. In case of a failed dependency
  it comments out the failed plugin in the config that it writes.
* Mon Apr  7 2008 pth@suse.de
- Fix paths for lua and php in examples
* Fri Mar 28 2008 pth@suse.de
- Update to 2.18. Changes since 2.12:
  - Lots of bugs fixed, see ChangeLog for detailed list.
  - in -Tps use a new number formatter that suppresses trailing 0.
  - support tcl/tk-8.5
  - support gcc-4.3
  - support for node usershapes/images in svg format
  - install: perl, php, python, ruby, tcl, bindings in
    language-specified directories
  - add arrowhead scaling with edge penwidth
  - add "folder" node shape
  - add "smyna" large graph view (thanks Arif) (not yet included
    in binary distros)
  * 2.16.1
  - Improvements to PHP binding
  - Improvements to OCAML binding
  - Make regression tests run from the build tree, rather than require
    installation
  - Repair freetype detection on RedHat-7 (Yes, people still use it!!)
  - Fix zoom-at-mouse-location in -Txlib and -Tgtk
  - Fix some dotty regressions
  * 2.15
  - new regression test suite
  - new cgraph library (will eventually replace graph and agraph)
  - add "image" and "imagescale" for simpler support for images in nodes
  - add "tab" "box3d" and "component" shapes.  - Diomidis Spinellis
  - replace arith.h in distro
  - add functions to access version info to avoid need for gvcint.h
  - Fix problem with irregular character spacing at 96dpi in pango/cairo
    output formats.
  - Add gdk_pixbuf plugin providing: .bmp .ico .jpg .png .tif
  - Add DevIL plugin providing: .bmp .jpg .png .tif .tga
  - Extend GD plugin to provide a backend to cairo for: .gif .jpg .png .gd
    .gd2 .wbmp  <- gifs are now antialiased
  - Rework plugin framework to separate device from renderer, and to
    autoload load dependendent plugins
  - show defaults in output from: ./configure --help
  - add more info to dot -v  and dot -v2 debug outputs
  - various issues with CR/LF in windows, but not in binary outputs.
  * 2.14.1
  - Add xdot parsing library to source distros
  - graphviz.spec fixes for rpm distros from Gareth Armstrong
  - moved language binding man pages to mann
    (gv_php.n, gv_ocaml.n, etc.)
  - New access functions for version info in GVC_t - permits
    gvcint.h to be private.
  * 2.14:
  - Using system version of libgd if gd-2.0.34 or later.
    internal copy of gd updated to gd-2.0.35.
  - Updated GVGUI viewer for Windows
  - Added support for selection of edge routing types:
    line, polyline, orthogonal, spline
  - Added -Tvml support
- Adapt the patch to allow ^LT_(CURRENT|REVISION|AGE)$ in
  configure script and reenable the use of these variables.
* Thu Mar 13 2008 schwab@suse.de
- Allow ^LT_(CURRENT|REVISION|AGE)$ in configure script.
- Remove broken autoconf macros.
* Fri Oct 26 2007 pth@suse.de
- Add missing includes.
* Mon Aug 13 2007 pth@suse.de
- lib/sfio/sfhdr.h(SFSETLOCALE): fix test for null pointer.
- use -fno-strict-aliasing for gv_php
* Fri May 11 2007 ro@suse.de
- added get_release_number.sh to sync rel-number between
  graphviz and graphviz-plugins
* Wed May  9 2007 ro@suse.de
- split off plugins to separate specfile to break build cycles
* Tue May  8 2007 pth@suse.de
- Update to 2.12
  - PostScript output had an extraneous '%%' character on the first line,
    which would cause printing to fail.
  - Text handling, during both sizing and layout, incorrectly handled
    empty lines such as label="\nabc".
  - HTML-like tables had been changed to use too much vertical space,
    to possibly use the wrong font in calculating the height of a line,
    and to use the wrong offset when moving the baseline from one line to
    the next.
  - dot - New pango+cairo renderer plugin (was in separate graphviz-cairo tree).
  - - -Tpng now uses cairo   (-Tpng:gd for old gd based renderer)
  - - -Tpdf now available
  - - -Tps:cairo now available (-Tps is a direct ps renderer not based on
    cairo)
  - - -Tsvg:cairo now available (-Tsvg is a direct svg renderer not based
    on cairo)
  - - -Txlib now available -- "dot -Tx11 foo.dot"  watches foo.dot with
    inotify and updates
  - - -Tgtk now available -- eventually to provide a graph editing capability
  - not fully working
  - - -Tswf "Flash" now available using the ming library. Currently has
    incomplete font support and not yet in Fedora rpms because ming not
    yet available as rpm.
  - remove hard gd dependencies from dot.  gd renderers now provided
    as optional plugin.   Deprecated, but required for -Tjpg, -Tgif and -Tvrml.
  - gvpr - Add kindOf function, plus functions to set and get default values
  - dot - Implement esep attribute to allow graph to specify room
    around nodes for spline routing.
  - neato - add vpsc library and DIGCOLA
  - neato - add IPSEPCOLA additions from Tim Dwyer
  - move: -Tps, -Tfig, -Tsvg, -Timap/ismap/cmap/cmapx, -Tdot/xdot,
    from codegens to a "core" plugin.
  - dot - new usershape plugin mechanism potentially supporting
    a wider range of input shape format -> output format combinations.
    display on changes
  - dot - new -O switch to automatically generate output file
    names based on the input filename and the -T value.
    e.g.  "dot -Tpng -O *.dot"
    Also works for case of multiple graphs in a single input file.
  - add support for "Brewer" color nameset
  - move reusable .so libraries to $PREFIX/lib per frequent request
    from Debian community.   Plugin .so's remain in $PREFIX/lib/graphviz.
  - (POTENTIAL INCOMPATIBILITY) The default input scaling, in the
    absence of a "-s" switch, has been changed from inches to points.
    The new behavior of "neato" is equivalent to "neato -s72".
    The old behavior can be restored with "neato -s1".
    The purpose of this change is to avoid a Frequently-Made-Mistake
    when using "neato -n" to process a previously generated layout.
    Previously it was necessary to use "neato -n -s72", but with this
    change the default matches dot's output and the "-s72" is not required.
  - Added pseudo layout engines: "dot -Knop" and dot -Knop1" equivalent
    to "neato -n"
  - Added pseodo layout engine: "dot -Knop2" equivalent to "neato -n2"
  - Add support for color namespaces; add Brewer color data
  - Add support for simulated duplex edges using parallel edges:
    head arrow takes first color, tail arrow takes second color.
  - Add a small pad region around graph renderings to allow for finite
    penwidths at the drawing edges
  - Add protonode(g) and E=protoedge(g) functions to simplify language
    bindings.
  - Add special purpose code to deal with html labels from language
    bindings.
- Split off language support into subpackages.
- build php,ruby,C#,python,guile and java support in addition to tcl
- swig >= 1.3.21 differentiates between php4 and php5, so adapt
  configure test.
- Don't move tcl libraries to _libdir but instead add the graphviz
  sublibrary paths via /etc/ld.so.conf.d
- Use SONAMEs to generate pkgIndex.tcl. That way tcl can actually
  load the libraries via 'package require'
- Don't compare pointer with string literal.
* Thu May  3 2007 prusnak@suse.cz
- changed expat to libexpat-devel in [Build]Requires
* Thu Mar 29 2007 aj@suse.de
- Add bison to BuildRequires.
* Fri Aug 11 2006 pth@suse.de
- Adapt to new X11 paths.
* Mon Apr  3 2006 pnemec@suse.cz
- add pkgconfig files to devel package
* Sun Feb 19 2006 aj@suse.de
- Reduce BuildRequires.
* Thu Feb  9 2006 pth@suse.de
- Fix segfault in neato when using splines (#144275)
* Fri Feb  3 2006 pth@suse.de
- Fix swig template to include declaration.
- Fix BuildRequires
- Fix dependencies for -devel package
* Thu Nov 24 2005 agruen@suse.de
- Add missing plugin config file.
- Fix gcc aliasing bugs.
* Mon Aug 29 2005 agruen@suse.de
- Update to version 2.6: numerous bugfixes.
* Tue Aug  9 2005 agruen@suse.de
- fix-pkgIndex.diff: Fix tcl library search for "package require
  Tkspline" and similar statements by (a) moving the tcl/tk
  libraries from _libdir/graphviz/ to _libdir/, and removing
  path names from library names in pkgIndex.tcl so that 32bit
  and 64bit libraries are searched as appropriate.
* Mon Aug  1 2005 ro@suse.de
- move pkgIndex.tcl to /usr/share
* Thu Feb 10 2005 agruen@suse.de
- Update to version 2.2.
- Drop graphviz-graphs subpackage.
* Sun Aug 29 2004 garloff@suse.de
- Drop EULA notification message.
* Sat Mar 27 2004 sndirsch@suse.de
- update to graphviz-1.12
  * general
  - rename bcc -> bcomps to avoid name conflict with
    "Bruce's C Compiler" on Redhat distributions.
  - all build without X11 (fix problem in lefty tree)
  - remove from distribution:
    dag, fdp, geo, grid, incr, shape, tcldgr, tcldgl
  * dotneato
  - fix "brown-bag" problem resulting in PNG and JPEG errors on
    RH8 and RH9.
- removed hunks for dag, fdp, grid, tcldgl from codecleanup patch;
  directories were dropped upstream (see 1.12 changelog above)
- no need to rename bcc any longer (see 1.12 changelog above)
- removed libtcldgl/libtcldgr (see 1.12 changelog above)
* Mon Mar  8 2004 garloff@suse.de
- Rename bcc to bcc-graphviz due to conflict with bcc from dev86.
* Mon Mar  1 2004 garloff@suse.de
- Update to graphviz-1.11:
  * Drop lots of patches (merged upstream) ;-)
  * dotneato: add -Gviewport, fix memleak in gdft, clean up calc
    of whitespace around labels
* Wed Feb 25 2004 garloff@suse.de
- Update to graphviz-1.10:
  * enhanced gpr: string matching, lock primitive to save graphs
  * zoomable 2 1/2 D graph viewer (Java)
  * neato -gpack
* Fri Jan 16 2004 meissner@suse.de
- Change freetype detection to new one, so the internal libGD is build
  against it again.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Oct  6 2003 kukuk@suse.de
- Remove curl (source code does not use it) and lynx from
  neededforbuild.
* Mon Jul 28 2003 ro@suse.de
- updated neededforbuild
* Tue May 13 2003 pthomas@suse.de
- Add hacks to work around problems with libtool 1.5.
* Mon Apr 14 2003 pthomas@suse.de
- Get rid of nearly all compiler warnings.
* Mon Apr  7 2003 pthomas@suse.de
- Use posix-2001 conforming syntax for sort.
* Fri Feb  7 2003 pthomas@suse.de
- Update to 1.9
- Split off subpackages devel, graphs and tcl like
  it's done in the specfile included with graphviz.
- remove obsolete patches
* Wed Jan 29 2003 ro@suse.de
- fix png library detection in configure
- removed perl-GD and blt from neededforbuild
* Wed Jan  8 2003 ro@suse.de
- fixed configure.in
* Thu Nov 14 2002 tcrhak@suse.cz
- fixed for new bison: end rules with semicolons
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Sat Aug 10 2002 aj@suse.de
- Fix typo in license.
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Tue Jul  2 2002 garloff@suse.de
- Update to 1.8.6:
  * FPU handling fix got included
  * arch independent stuff in /usr/share/graphviz now
  * arrow fixes and improvements and more arrow types
  * new pack option to neato
  * bugfixes
- Change licensor from SuSE GmbH to SuSE Linux AG
* Wed May 22 2002 garloff@suse.de
- Add prune binary and man page to file list.
* Fri May 10 2002 garloff@suse.de
- Fix FPU excpetion handling. (Use feenableexcept() rather than
  _FPU_GETCW(), if available.)
* Wed May  8 2002 garloff@suse.de
- Update to graphviz-1.8.5:
  * fixed various Win and MacOSX probs
  * minimal Type1 font support
  * webdot.cgi perl script accepts same args as webgot.tcl now
  * various SVG enhancements and fixes
  * various portability/64bit fixes
  * various bug fixes
* Fri May  3 2002 meissner@suse.de
- %%_lib fixes (to find tclConfig.sh and tkConfig.sh)
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Jan 28 2002 garloff@suse.de
- Some more missing decls found and fixed.
* Mon Jan 28 2002 garloff@suse.de
- Added patch to fix lots of warnings (and potential bugs on 64bit
  platforms).
* Mon Jan 28 2002 garloff@suse.de
- Pass TK_DEFS to gcc for tkspline (which uses tkInt.h)
* Mon Jan 28 2002 garloff@suse.de
- Update to 1.7.16:
  * Various bug fixes
  * Support for xfig, svgz,
  * Text output improvements
  * New twopi tool
- Drop patches that have been included in official source ball.
* Tue May 22 2001 garloff@suse.de
- Fix cast warnings on 64bit archs and add missing includes
  where necessary.
* Wed May  9 2001 garloff@suse.de
- Cleanup patches.
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Mon Apr 30 2001 garloff@suse.de
- Update to release 1.7.6 with lots of bugfixes:
  * Lots of font related fixes
  * Fix various bugs WRT labels
  * UTF-8 fixes
  * cluster and neato layout fixes
  * -Timap (mouse sensitive graphs for web pages) fixes
  * PNG by default does white background now instead of transp.
- New features in 1.7.6:
  * New graph processing tools: acyclic, ccomps, colorize, gc,
    gpr, nop, sccmap, tred, unflatten (See ChangeLog for details)
- Spec file: Consistently use %%{prefix}
* Thu Mar 22 2001 ro@suse.de
- changed neededforbuild to freetype2
- updated to 1.7.5 for freetype2
* Mon Feb 26 2001 uli@suse.de
- fixed for new glibc
* Fri Jan 19 2001 garloff@suse.de
- Assorted patches from Stephen C. North to
  * fix runtime error in graphs having multiple nodes in the min
    or max rank set
  * fix layout thinko (mincross)
* Sat Dec 16 2000 garloff@suse.de
- Update to 1.7.4:
  * various fixes
  * support various linestyles
  * Remove Tcldot dependence on libgdtclft
  * support for long label strings (fixing a reported crash)
* Tue Dec 12 2000 garloff@suse.de
- Specfile cleanups.
* Mon Dec 11 2000 garloff@suse.de
- Update to 1.7.3:
  * Better font drawing support
  * Bugfixes
- Removed most explicit Requires: from spec, as AutoReqProv works
  just fine.
- Split off webdot.
* Wed Nov 29 2000 ro@suse.de
- changed neededforbuild <tcld> to <tcl-devel>
* Wed Nov  8 2000 ro@suse.de
- fixed neededforbuild gd -> perl-GD
* Wed Nov  1 2000 garloff@suse.de
- Use %%{?suse_update_config} -> support for S/390 added
* Tue Oct 31 2000 garloff@suse.de
- Update to 1.7: * dot/neato again separate binaries
  * 64 bit patches integrated
  * Some bugfixes and feature enhancements
* Wed Oct 18 2000 garloff@suse.de
- Change the wording of the license notification to match the
  wording from the letter from AT&T.
* Tue Sep 19 2000 garloff@suse.de
- Cleanups for 64 bit archs.
* Mon Sep 18 2000 garloff@suse.de
- Add a notification for the sysadmin, that (s)he and the users
  need to agree with the license termn in MINTERMS.txt. According
  to "Stephen C. North" <north@research.att.com>, this is all that
  needs to be done to fulfill the license requirements.
* Wed Sep  6 2000 garloff@suse.de
- LICENSOR is SuSE: Filled in MINTERMS.txt
* Tue Sep  5 2000 garloff@suse.de
- Creation of package graphviz-1.6
- Fix lneato Makefile to install into $DESTDIR
